## v0.0.5 (2025-12-30)

### 🔀 Others
- modify projects scripts
- modify projects scripts

## v0.0.4 (2025-12-30)

### 🔀 Others
- modify projects scripts

## v0.0.3 (2025-12-30)

### 🔀 Others
- support syncmeta

## v0.0.2 (2025-12-30)

### 🔀 Others
- init
